@@ -4,7 +4,7 @@
 <context>
     <name>KvManager::AboutDialog</name>
     <message>
-        <location filename="../../about.ui" line="167"/>
+        <location filename="../../about.ui" line="169"/>
         <source>License</source>
         <translation>Licencia</translation>
     </message>
@@ -14,12 +14,12 @@
     <message>
         <location filename="../../kvantummanager.ui" line="12"/>
         <source>Kvantum Manager</source>
-        <translation>Kvantum manažér</translation>
+        <translation>Správca Kvantum</translation>
     </message>
     <message>
         <location filename="../../kvantummanager.ui" line="38"/>
         <source>Install/Update Theme</source>
-        <translation>Inštalovať/aktualizovať tému</translation>
+        <translation>Inštalácia/aktualizácia motívu</translation>
     </message>
     <message>
         <location filename="../../kvantummanager.ui" line="44"/>
@@ -30,35 +30,35 @@
         <location filename="../../kvantummanager.ui" line="76"/>
         <source>Select a Kvantum
 theme folder</source>
-        <translation>Vyberte adresár
-témy Kvantum</translation>
+        <translation>Vybrať priečinok
+motívov Kvantum</translation>
     </message>
     <message>
         <location filename="../../kvantummanager.ui" line="113"/>
         <source>Add this theme to the list of themes that
 Kvantum can use in addition to its own themes.</source>
-        <translation>Pridať túto tému do zoznamu tém, ktoré
-Kvantum môže použiť okrem svojich vlastných tém.</translation>
+        <translation>Pridá tento motív do zoznamu motívov, ktoré môže
+nástroj Kvantum dodatočne použiť s vlastnými motívmi.</translation>
     </message>
     <message>
         <location filename="../../kvantummanager.ui" line="117"/>
         <source>Install this theme</source>
-        <translation>Inštalovať túto tému</translation>
+        <translation>Inštalovať tento motív</translation>
     </message>
     <message>
         <location filename="../../kvantummanager.ui" line="138"/>
         <source>Change/Delete Theme</source>
-        <translation>Zmeniť/vymazať tému</translation>
+        <translation>Zmena/odstránenie motívu</translation>
     </message>
     <message>
         <location filename="../../kvantummanager.ui" line="144"/>
         <source>Select a theme:</source>
-        <translation>Vyberte tému:</translation>
+        <translation>Vyberte motív:</translation>
     </message>
     <message>
         <location filename="../../kvantummanager.ui" line="191"/>
         <source>Delete this theme</source>
-        <translation>Zmazať túto tému</translation>
+        <translation>Odstrániť tento motív</translation>
     </message>
     <message>
         <location filename="../../kvantummanager.ui" line="198"/>
@@ -66,28 +66,28 @@ Kvantum môže použiť okrem svojich vlastných tém.</translation>
 
 A disabled button means that
 the theme is already used.</source>
-        <translation>Uskutočniť, aby Kvantum používal túto tému!
+        <translation>Nariadi nástroju Kvantum použiť tento motív!
 
-Vypnuté tlačítko znamená, že
-téma sa momentálne používa.</translation>
+Zakázané tlačidlo znamená, že
+motív sa už používa.</translation>
     </message>
     <message>
         <location filename="../../kvantummanager.ui" line="204"/>
         <source>Use this theme</source>
-        <translation>Použiť túto tému</translation>
+        <translation>Použiť tento motív</translation>
     </message>
     <message>
         <location filename="../../kvantummanager.ui" line="257"/>
         <source>Configure Active Theme</source>
-        <translation>Konfigurovať aktívnu tému</translation>
+        <translation>Konfigurácia aktívneho motívu</translation>
     </message>
     <message>
         <location filename="../../kvantummanager.ui" line="321"/>
         <source>Revert to the default (root)
 settings of this theme.
 (Ctrl+Z)</source>
-        <translation>Vrátiť na preddefinované (root)
-nastavenia tejto témy.
+        <translation>Návrat k predvoleným (správca)
+nastaveniam tohto motívu.
 (Ctrl+Z)</translation>
     </message>
     <message>
@@ -109,7 +109,7 @@ nastavenia tejto témy.
         <location filename="../../kvantummanager.ui" line="342"/>
         <source>Save this configuration
 (Ctrl+S)</source>
-        <translation>Uložiť tieto nastavenia
+        <translation>Uloží túto konfiguráciu
 (Ctrl+S)</translation>
     </message>
     <message>
@@ -136,12 +136,12 @@ nastavenia tejto témy.
     <message>
         <location filename="../../kvantummanager.ui" line="396"/>
         <source>Transparent Dolphin view</source>
-        <translation>Priehľadný pohľad Dolphin</translation>
+        <translation>Priehľadné zobrazenie aplikácie Dolphin</translation>
     </message>
     <message>
         <location filename="../../kvantummanager.ui" line="424"/>
         <source>Normal font for default push buttons</source>
-        <translation>Normálne písmo pre predvolené tlačidlá</translation>
+        <translation>Normálne písmo pre predvolené stláčacie tlačidlá</translation>
     </message>
     <message>
         <location filename="../../kvantummanager.ui" line="444"/>
@@ -174,12 +174,12 @@ with LXQt Session Settings.</source>
     <message>
         <location filename="../../kvantummanager.ui" line="480"/>
         <source>Transparent view for PCManFM-qt</source>
-        <translation>Priehľadný pohľad pre PCManFM-qt</translation>
+        <translation>Priehľadné zobrazenie pre aplikáciu  PCManFM-qt</translation>
     </message>
     <message>
         <location filename="../../kvantummanager.ui" line="495"/>
         <source>Iconless menus</source>
-        <translation>Menu bez ikôn</translation>
+        <translation>Ponuky bez ikon</translation>
     </message>
     <message>
         <location filename="../../kvantummanager.ui" line="510"/>
@@ -236,7 +236,7 @@ the highlight color!</source>
     <message>
         <location filename="../../kvantummanager.ui" line="588"/>
         <source>Transparent menu title</source>
-        <translation>Priehľadný názov menu</translation>
+        <translation>Priehľadný titulok ponuky</translation>
     </message>
     <message>
         <location filename="../../kvantummanager.ui" line="651"/>
@@ -254,7 +254,7 @@ the highlight color!</source>
     <message>
         <location filename="../../kvantummanager.ui" line="611"/>
         <source>Respect dark themes</source>
-        <translation>Rešpektovať tmavé témy</translation>
+        <translation>Brať ohľad na tmavé motívy</translation>
     </message>
     <message>
         <location filename="../../kvantummanager.ui" line="689"/>
@@ -273,7 +273,7 @@ reduced by other means.</source>
     <message>
         <location filename="../../kvantummanager.ui" line="697"/>
         <source>Opacity of disabled icons:</source>
-        <translation>Krycia schopnosť deaktivovaných symbolov:</translation>
+        <translation>Krytie zakázaných ikon:</translation>
     </message>
     <message>
         <location filename="../../kvantummanager.ui" line="630"/>
@@ -294,7 +294,7 @@ as far as possible.</source>
     <message>
         <location filename="../../kvantummanager.ui" line="747"/>
         <source>LXQt main menu icon size:</source>
-        <translation>Veľkosť ikôn v menu LXQt:</translation>
+        <translation>Veľkosť ikon hlavnej ponuky prostredia LXQt:</translation>
     </message>
     <message>
         <location filename="../../kvantummanager.ui" line="762"/>
@@ -313,7 +313,7 @@ as far as possible.</source>
     <message>
         <location filename="../../kvantummanager.ui" line="776"/>
         <source>Compositing &amp;&amp; General Look</source>
-        <translation>Zloženie &amp;&amp; Všeobecný vzhľad</translation>
+        <translation>Skladba a všeobecný vzhľad</translation>
     </message>
     <message>
         <location filename="../../kvantummanager.ui" line="975"/>
@@ -452,7 +452,7 @@ Usually, a value of 2 is enough.</source>
     <message>
         <location filename="../../kvantummanager.ui" line="821"/>
         <source>Menu:</source>
-        <translation type="unfinished"></translation>
+        <translation>Ponuka:</translation>
     </message>
     <message>
         <location filename="../../kvantummanager.ui" line="828"/>
@@ -611,7 +611,7 @@ windows if this theme distinguishes between them?</source>
     <message>
         <location filename="../../kvantummanager.ui" line="1352"/>
         <source>Font size</source>
-        <translation type="unfinished"></translation>
+        <translation>Veľkosť písma</translation>
     </message>
     <message>
         <location filename="../../kvantummanager.ui" line="1368"/>
@@ -1155,7 +1155,7 @@ i.e., there is no border between them.</source>
     <message>
         <location filename="../../kvantummanager.ui" line="1996"/>
         <source>Scrollable menus</source>
-        <translation type="unfinished"></translation>
+        <translation>Rolovateľné ponuky</translation>
     </message>
     <message>
         <location filename="../../kvantummanager.ui" line="1644"/>
@@ -1210,7 +1210,7 @@ the Ctrl key before pressing the button.</source>
     <message>
         <location filename="../../kvantummanager.ui" line="2033"/>
         <source>Application Themes</source>
-        <translation type="unfinished"></translation>
+        <translation>Motívy aplikácií</translation>
     </message>
     <message>
         <location filename="../../kvantummanager.ui" line="2039"/>
@@ -1220,27 +1220,27 @@ the Ctrl key before pressing the button.</source>
     <message>
         <location filename="../../kvantummanager.ui" line="2074"/>
         <source>Installed Theme</source>
-        <translation type="unfinished"></translation>
+        <translation>Nainštalovaný motív</translation>
     </message>
     <message>
         <location filename="../../kvantummanager.ui" line="2090"/>
         <source>Application(s)</source>
-        <translation type="unfinished"></translation>
+        <translation>Aplikácie</translation>
     </message>
     <message>
         <location filename="../../kvantummanager.ui" line="2119"/>
         <source>app1,app2,app3</source>
-        <translation type="unfinished"></translation>
+        <translation>aplikácia1,aplikácia2,aplikácia3</translation>
     </message>
     <message>
         <location filename="../../kvantummanager.ui" line="2147"/>
         <source>Remove List</source>
-        <translation type="unfinished"></translation>
+        <translation>Odstrániť zoznam</translation>
     </message>
     <message>
         <location filename="../../kvantummanager.ui" line="2154"/>
         <source>Save the current list of apps</source>
-        <translation type="unfinished"></translation>
+        <translation>Uloží aktuálny zoznam aplikácií</translation>
     </message>
     <message>
         <location filename="../../kvantummanager.ui" line="2157"/>
@@ -1251,33 +1251,34 @@ the Ctrl key before pressing the button.</source>
         <location filename="../../kvantummanager.ui" line="2184"/>
         <location filename="../../kvantummanager.ui" line="2190"/>
         <source>Ctrl+Q</source>
-        <translation type="unfinished"></translation>
+        <translation>Ctrl+Q</translation>
     </message>
     <message>
         <location filename="../../kvantummanager.ui" line="2187"/>
         <source>Quit</source>
-        <translation type="unfinished"></translation>
+        <translation>Ukončiť</translation>
     </message>
     <message>
         <location filename="../../kvantummanager.ui" line="2200"/>
         <source>Preview the active theme
 or update its preview.</source>
-        <translation type="unfinished"></translation>
+        <translation>Zobrazí náhľad aktuálneho motívu
+alebo aktualizuje jeho náhľad.</translation>
     </message>
     <message>
         <location filename="../../kvantummanager.ui" line="2204"/>
         <source>Preview</source>
-        <translation type="unfinished"></translation>
+        <translation>Náhľad</translation>
     </message>
     <message>
         <location filename="../../kvantummanager.ui" line="2211"/>
         <source>About</source>
-        <translation type="unfinished"></translation>
+        <translation>O aplikácii</translation>
     </message>
     <message>
         <location filename="../../kvantummanager.ui" line="2234"/>
         <source>What&apos;s This?</source>
-        <translation type="unfinished"></translation>
+        <translation>Čo je toto?</translation>
     </message>
     <message>
         <location filename="../../kvantummanager.ui" line="2237"/>
@@ -1287,12 +1288,12 @@ or update its preview.</source>
     <message>
         <location filename="../../kvantummanager.ui" line="2240"/>
         <source>Help</source>
-        <translation type="unfinished"></translation>
+        <translation>Pomocník</translation>
     </message>
     <message>
         <location filename="../../KvantumManager.cpp" line="329"/>
         <source>Open Kvantum Theme Folder...</source>
-        <translation type="unfinished"></translation>
+        <translation>Otvorenie priečinku motívov Kvantum...</translation>
     </message>
     <message>
         <location filename="../../KvantumManager.cpp" line="190"/>
@@ -1307,19 +1308,19 @@ or update its preview.</source>
         <location filename="../../KvantumManager.cpp" line="660"/>
         <location filename="../../KvantumManager.cpp" line="676"/>
         <source>Kvantum</source>
-        <translation type="unfinished"></translation>
+        <translation>Kvantum</translation>
     </message>
     <message>
         <location filename="../../KvantumManager.cpp" line="600"/>
         <source>First you have to delete its modified version!</source>
-        <translation type="unfinished"></translation>
+        <translation>Najskôr musíte odstrániť jeho upravenú verziu!</translation>
     </message>
     <message>
         <location filename="../../KvantumManager.cpp" line="624"/>
         <location filename="../../KvantumManager.cpp" line="778"/>
         <location filename="../../KvantumManager.cpp" line="2779"/>
         <source>Confirmation</source>
-        <translation type="unfinished"></translation>
+        <translation>Potvrdenie</translation>
     </message>
     <message>
         <location filename="../../KvantumManager.cpp" line="739"/>
@@ -1334,7 +1335,7 @@ or update its preview.</source>
     <message>
         <location filename="../../KvantumManager.cpp" line="969"/>
         <source>Theme changed to %1.</source>
-        <translation type="unfinished"></translation>
+        <translation>Motív bol zmenený na %1.</translation>
     </message>
     <message>
         <location filename="../../KvantumManager.cpp" line="517"/>
@@ -1351,22 +1352,22 @@ or update its preview.</source>
     <message>
         <location filename="../../KvantumManager.cpp" line="105"/>
         <source>Single Click</source>
-        <translation type="unfinished"></translation>
+        <translation>Jednoduché kliknutie</translation>
     </message>
     <message>
         <location filename="../../KvantumManager.cpp" line="106"/>
         <source>Double Click</source>
-        <translation type="unfinished"></translation>
+        <translation>Dvojité kliknutie</translation>
     </message>
     <message>
         <location filename="../../KvantumManager.cpp" line="109"/>
         <source>Icon Only</source>
-        <translation type="unfinished"></translation>
+        <translation>Iba ikona</translation>
     </message>
     <message>
         <location filename="../../KvantumManager.cpp" line="110"/>
         <source>Text Only</source>
-        <translation type="unfinished"></translation>
+        <translation>Iba text</translation>
     </message>
     <message>
         <location filename="../../KvantumManager.cpp" line="111"/>
@@ -1381,32 +1382,32 @@ or update its preview.</source>
     <message>
         <location filename="../../KvantumManager.cpp" line="115"/>
         <source>KDE Layout</source>
-        <translation type="unfinished"></translation>
+        <translation>Rozloženie prostredia KDE</translation>
     </message>
     <message>
         <location filename="../../KvantumManager.cpp" line="116"/>
         <source>Gnome Layout</source>
-        <translation type="unfinished"></translation>
+        <translation>Rozloženie prostredia GNOME</translation>
     </message>
     <message>
         <location filename="../../KvantumManager.cpp" line="117"/>
         <source>Mac Layout</source>
-        <translation type="unfinished"></translation>
+        <translation>Rozloženie systému Mac</translation>
     </message>
     <message>
         <location filename="../../KvantumManager.cpp" line="118"/>
         <source>Windows Layout</source>
-        <translation type="unfinished"></translation>
+        <translation>Rozloženie systému Windows</translation>
     </message>
     <message>
         <location filename="../../KvantumManager.cpp" line="119"/>
         <source>Android Layout</source>
-        <translation type="unfinished"></translation>
+        <translation>Rozloženie systému Android</translation>
     </message>
     <message>
         <location filename="../../KvantumManager.cpp" line="121"/>
         <source>Titlebar</source>
-        <translation type="unfinished"></translation>
+        <translation>Záhlavie</translation>
     </message>
     <message>
         <location filename="../../KvantumManager.cpp" line="122"/>
@@ -1426,12 +1427,12 @@ or update its preview.</source>
     <message>
         <location filename="../../KvantumManager.cpp" line="519"/>
         <source>Please fix that first!</source>
-        <translation type="unfinished"></translation>
+        <translation>Prosím, najskôr to opravte!</translation>
     </message>
     <message>
         <location filename="../../KvantumManager.cpp" line="531"/>
         <source>This file cannot be removed:</source>
-        <translation type="unfinished"></translation>
+        <translation>Tento súbor sa nedá odstrániť:</translation>
     </message>
     <message>
         <location filename="../../KvantumManager.cpp" line="550"/>
@@ -1449,7 +1450,7 @@ or update its preview.</source>
         <location filename="../../KvantumManager.cpp" line="563"/>
         <location filename="../../KvantumManager.cpp" line="573"/>
         <source>Please select another directory!</source>
-        <translation type="unfinished"></translation>
+        <translation>Prosím, zvoľte iný adresár!</translation>
     </message>
     <message>
         <location filename="../../KvantumManager.cpp" line="562"/>
@@ -1459,12 +1460,12 @@ or update its preview.</source>
     <message>
         <location filename="../../KvantumManager.cpp" line="572"/>
         <source>This is not a Kvantum theme folder!</source>
-        <translation type="unfinished"></translation>
+        <translation>Toto nie je priečinok s motívmi nástroja Kvantum!</translation>
     </message>
     <message>
         <location filename="../../KvantumManager.cpp" line="599"/>
         <source>The theme already exists in modified form.</source>
-        <translation type="unfinished"></translation>
+        <translation>Motív už existuje v upravenej forme.</translation>
     </message>
     <message>
         <location filename="../../KvantumManager.cpp" line="614"/>
@@ -1474,17 +1475,17 @@ or update its preview.</source>
     <message>
         <location filename="../../KvantumManager.cpp" line="615"/>
         <source>Please choose another directory!</source>
-        <translation type="unfinished"></translation>
+        <translation>Prosím, zvoľte iný adresár!</translation>
     </message>
     <message>
         <location filename="../../KvantumManager.cpp" line="625"/>
         <source>The theme already exists.</source>
-        <translation type="unfinished"></translation>
+        <translation>Motív už existuje.</translation>
     </message>
     <message>
         <location filename="../../KvantumManager.cpp" line="626"/>
         <source>Do you want to overwrite it?</source>
-        <translation type="unfinished"></translation>
+        <translation>Chcete ho prepísať?</translation>
     </message>
     <message>
         <location filename="../../KvantumManager.cpp" line="661"/>
@@ -1531,7 +1532,7 @@ or update its preview.</source>
     <message>
         <location filename="../../KvantumManager.cpp" line="1813"/>
         <source>No description</source>
-        <translation type="unfinished"></translation>
+        <translation>Bez popisu</translation>
     </message>
     <message>
         <location filename="../../KvantumManager.cpp" line="2266"/>
@@ -1546,7 +1547,7 @@ or update its preview.</source>
     <message>
         <location filename="../../KvantumManager.cpp" line="2673"/>
         <source>Configuration saved.</source>
-        <translation type="unfinished"></translation>
+        <translation>Konfigurácia bola uložená.</translation>
     </message>
     <message>
         <location filename="../../KvantumManager.cpp" line="2780"/>
@@ -1572,7 +1573,7 @@ or update its preview.</source>
         <location filename="../../KvantumManager.cpp" line="2975"/>
         <location filename="../../KvantumManager.cpp" line="2976"/>
         <source>About Kvantum Manager</source>
-        <translation type="unfinished"></translation>
+        <translation>O správcovi Kvantum</translation>
     </message>
     <message>
         <location filename="../../KvantumManager.cpp" line="2975"/>
@@ -1602,7 +1603,7 @@ or update its preview.</source>
     <message>
         <location filename="../../KvantumManager.cpp" line="529"/>
         <source>This directory cannot be removed:</source>
-        <translation type="unfinished"></translation>
+        <translation>Tento adresár sa nedá odstrániť:</translation>
     </message>
     <message>
         <location filename="../../KvantumManager.cpp" line="536"/>
@@ -1622,17 +1623,17 @@ or update its preview.</source>
     <message>
         <location filename="../../main.cpp" line="139"/>
         <source>Kvantum</source>
-        <translation type="unfinished"></translation>
+        <translation>Kvantum</translation>
     </message>
     <message>
         <location filename="../../main.cpp" line="140"/>
         <source>Kvantum is not installed on your system.</source>
-        <translation type="unfinished"></translation>
+        <translation>Nástroj Kvantum nie je nainštalovaný vo vašom systéme.</translation>
     </message>
     <message>
         <location filename="../../main.cpp" line="141"/>
         <source>Please first install the Kvantum style plugin!</source>
-        <translation type="unfinished"></translation>
+        <translation>Prosím, najskôr nainštalujte zásuvný modul pre štýly nástroja Kvantum!</translation>
     </message>
 </context>
 </TS>
