@@ -146,12 +146,13 @@ og rullemenu pil</translation>
         <location filename="../../KvantumPreviewBase.ui" line="552"/>
         <source>Toolbutton with 32px PNG icon
 beside text</source>
-        <translation type="unfinished"></translation>
+        <translation>Værktøjsknap med 32px PNG ikon
+ved siden af tekst</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="366"/>
         <source>Push button with menu</source>
-        <translation type="unfinished"></translation>
+        <translation>Trykknap med menu</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="415"/>
@@ -164,510 +165,532 @@ height
 greater
 than
 width</source>
-        <translation type="unfinished"></translation>
+        <translation>Skift
+værktøjs
+knap
+
+til
+højde
+større
+end
+bredde</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="804"/>
         <source>Auto-raise</source>
-        <translation type="unfinished"></translation>
+        <translation>Automatisk hævning</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="825"/>
         <source>Radio/Check buttons</source>
-        <translation type="unfinished"></translation>
+        <translation>Radio/Check knapper</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="846"/>
         <location filename="../../KvantumPreviewBase.ui" line="859"/>
         <source>Simple radio button</source>
-        <translation type="unfinished"></translation>
+        <translation>Simpel radioknap</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="869"/>
         <location filename="../../KvantumPreviewBase.ui" line="880"/>
         <source>Multi-line
 radio button</source>
-        <translation type="unfinished"></translation>
+        <translation>flerstrenget
+Radio knap</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="891"/>
         <location filename="../../KvantumPreviewBase.ui" line="917"/>
         <source>Radio button with 32px SVG icon</source>
-        <translation type="unfinished"></translation>
+        <translation>Radio knap med 32px SVG ikon</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="940"/>
         <location filename="../../KvantumPreviewBase.ui" line="953"/>
         <source>Simple check box</source>
-        <translation type="unfinished"></translation>
+        <translation>Simpelt afkrydsningsfelt</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="963"/>
         <location filename="../../KvantumPreviewBase.ui" line="974"/>
         <source>Multi-line
 check box</source>
-        <translation type="unfinished"></translation>
+        <translation>flerstrenget
+afkrydsningsfelt</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="982"/>
         <location filename="../../KvantumPreviewBase.ui" line="995"/>
         <source>Tri-state check box</source>
-        <translation type="unfinished"></translation>
+        <translation>Tre tilstande afkrydsningsfelt</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="1005"/>
         <location filename="../../KvantumPreviewBase.ui" line="1019"/>
         <source>Check box with icon</source>
-        <translation type="unfinished"></translation>
+        <translation>Afkrydsningsfelt med ikon</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="1075"/>
         <source>Combos/Spins/Inputs</source>
-        <translation type="unfinished"></translation>
+        <translation>Kombinationer/Kørende/Valg</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="1109"/>
-        <location filename="../../KvantumPreviewBase.ui" line="1195"/>
-        <location filename="../../KvantumPreviewBase.ui" line="1264"/>
-        <location filename="../../KvantumPreviewBase.ui" line="1378"/>
-        <location filename="../../KvantumPreviewBase.ui" line="1450"/>
-        <location filename="../../KvantumPreviewBase.ui" line="1508"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1198"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1271"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1433"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1515"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1607"/>
         <source>Frameless (no difference)</source>
-        <translation type="unfinished"></translation>
+        <translation>Rammeløs (ingen forskel)</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="1120"/>
         <location filename="../../KvantumPreviewBase.ui" line="1159"/>
         <source>Standard combo box</source>
-        <translation type="unfinished"></translation>
+        <translation>Standard kombinationsboks</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="1129"/>
         <location filename="../../KvantumPreviewBase.ui" line="1168"/>
         <source>Standard combo box 1</source>
-        <translation type="unfinished"></translation>
+        <translation>Standard kombinationsboks 1</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="1137"/>
-        <location filename="../../KvantumPreviewBase.ui" line="1173"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1176"/>
         <source>Standard combo box 2</source>
-        <translation type="unfinished"></translation>
+        <translation>Standard kombinationsboks 2</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="1142"/>
-        <location filename="../../KvantumPreviewBase.ui" line="1178"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1181"/>
         <source>Standard combo box 3</source>
-        <translation type="unfinished"></translation>
+        <translation>Standard kombinationsboks 3</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="1147"/>
-        <location filename="../../KvantumPreviewBase.ui" line="1183"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1186"/>
         <source>Standard combo box 4</source>
-        <translation type="unfinished"></translation>
+        <translation>Standard kombinationsboks 4</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="1204"/>
-        <location filename="../../KvantumPreviewBase.ui" line="1273"/>
-        <location filename="../../KvantumPreviewBase.ui" line="1387"/>
-        <location filename="../../KvantumPreviewBase.ui" line="1459"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1207"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1280"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1442"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1524"/>
         <source>Frameless 1</source>
-        <translation type="unfinished"></translation>
+        <translation>Rammeløs 1</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="1209"/>
-        <location filename="../../KvantumPreviewBase.ui" line="1278"/>
-        <location filename="../../KvantumPreviewBase.ui" line="1392"/>
-        <location filename="../../KvantumPreviewBase.ui" line="1464"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1216"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1289"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1451"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1533"/>
         <source>Frameless 2</source>
-        <translation type="unfinished"></translation>
+        <translation>Rammeløs 2</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="1214"/>
-        <location filename="../../KvantumPreviewBase.ui" line="1283"/>
-        <location filename="../../KvantumPreviewBase.ui" line="1397"/>
-        <location filename="../../KvantumPreviewBase.ui" line="1469"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1221"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1294"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1456"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1538"/>
         <source>Frameless 3</source>
-        <translation type="unfinished"></translation>
+        <translation>Rammeløs 3</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="1219"/>
-        <location filename="../../KvantumPreviewBase.ui" line="1288"/>
-        <location filename="../../KvantumPreviewBase.ui" line="1402"/>
-        <location filename="../../KvantumPreviewBase.ui" line="1474"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1226"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1299"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1461"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1543"/>
         <source>Frameless 4</source>
-        <translation type="unfinished"></translation>
+        <translation>Rammeløs 4</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="1224"/>
-        <location filename="../../KvantumPreviewBase.ui" line="1407"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1231"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1304"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1466"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1548"/>
         <source>Frameless 5</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../KvantumPreviewBase.ui" line="1229"/>
-        <location filename="../../KvantumPreviewBase.ui" line="1412"/>
-        <source>Frameless 6</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../KvantumPreviewBase.ui" line="1234"/>
-        <location filename="../../KvantumPreviewBase.ui" line="1417"/>
-        <source>Frameless 7</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../KvantumPreviewBase.ui" line="1239"/>
-        <location filename="../../KvantumPreviewBase.ui" line="1422"/>
-        <source>Frameless 8</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../KvantumPreviewBase.ui" line="1244"/>
-        <location filename="../../KvantumPreviewBase.ui" line="1427"/>
-        <source>Frameless 9</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../KvantumPreviewBase.ui" line="1249"/>
-        <location filename="../../KvantumPreviewBase.ui" line="1432"/>
-        <source>Frameless 10</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../KvantumPreviewBase.ui" line="1300"/>
-        <location filename="../../KvantumPreviewBase.ui" line="1339"/>
-        <source>Editable combo box</source>
-        <translation type="unfinished"></translation>
+        <translation>Rammeløs 5</translation>
     </message>
     <message>
+        <location filename="../../KvantumPreviewBase.ui" line="1236"/>
         <location filename="../../KvantumPreviewBase.ui" line="1309"/>
-        <location filename="../../KvantumPreviewBase.ui" line="1348"/>
-        <source>Editable combo box 1</source>
-        <translation type="unfinished"></translation>
+        <location filename="../../KvantumPreviewBase.ui" line="1471"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1553"/>
+        <source>Frameless 6</source>
+        <translation>Rammeløs 6</translation>
     </message>
     <message>
+        <location filename="../../KvantumPreviewBase.ui" line="1241"/>
         <location filename="../../KvantumPreviewBase.ui" line="1314"/>
-        <location filename="../../KvantumPreviewBase.ui" line="1353"/>
-        <source>Editable combo box 2</source>
-        <translation type="unfinished"></translation>
+        <location filename="../../KvantumPreviewBase.ui" line="1476"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1558"/>
+        <source>Frameless 7</source>
+        <translation>Rammeløs 7</translation>
     </message>
     <message>
+        <location filename="../../KvantumPreviewBase.ui" line="1246"/>
         <location filename="../../KvantumPreviewBase.ui" line="1319"/>
-        <location filename="../../KvantumPreviewBase.ui" line="1358"/>
-        <source>Editable combo box 3</source>
-        <translation type="unfinished"></translation>
+        <location filename="../../KvantumPreviewBase.ui" line="1481"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1563"/>
+        <source>Frameless 8</source>
+        <translation>Rammeløs 8</translation>
     </message>
     <message>
+        <location filename="../../KvantumPreviewBase.ui" line="1251"/>
         <location filename="../../KvantumPreviewBase.ui" line="1324"/>
-        <location filename="../../KvantumPreviewBase.ui" line="1363"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1486"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1568"/>
+        <source>Frameless 9</source>
+        <translation>Rammeløs 9</translation>
+    </message>
+    <message>
+        <location filename="../../KvantumPreviewBase.ui" line="1256"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1329"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1491"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1573"/>
+        <source>Frameless 10</source>
+        <translation>Rammeløs 10</translation>
+    </message>
+    <message>
+        <location filename="../../KvantumPreviewBase.ui" line="1341"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1384"/>
+        <source>Editable combo box</source>
+        <translation>Redigerbar kombinationsboks</translation>
+    </message>
+    <message>
+        <location filename="../../KvantumPreviewBase.ui" line="1350"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1393"/>
+        <source>Editable combo box 1</source>
+        <translation>Redigerbar kombinationsboks 1</translation>
+    </message>
+    <message>
+        <location filename="../../KvantumPreviewBase.ui" line="1359"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1402"/>
+        <source>Editable combo box 2</source>
+        <translation>Redigerbar kombinationsboks 2</translation>
+    </message>
+    <message>
+        <location filename="../../KvantumPreviewBase.ui" line="1364"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1407"/>
+        <source>Editable combo box 3</source>
+        <translation>Redigerbar kombinationsboks 3</translation>
+    </message>
+    <message>
+        <location filename="../../KvantumPreviewBase.ui" line="1369"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1412"/>
         <source>Editable combo box 4</source>
-        <translation type="unfinished"></translation>
+        <translation>Redigerbar kombinationsboks 4</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="1482"/>
-        <location filename="../../KvantumPreviewBase.ui" line="1495"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1581"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1594"/>
         <source>Line-edit</source>
-        <translation type="unfinished"></translation>
+        <translation>Linjeredigering</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="1574"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1683"/>
         <source>Sliders/Scrolls/Progress/Dial</source>
-        <translation type="unfinished"></translation>
+        <translation>Skydere/Scrolls/Status/Tast</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2131"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2240"/>
         <source>Containers</source>
-        <translation type="unfinished"></translation>
+        <translation>Containere</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2152"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2261"/>
         <source>Header 1</source>
-        <translation type="unfinished"></translation>
+        <translation>Header 1</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2161"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2270"/>
         <source>Header 2</source>
-        <translation type="unfinished"></translation>
+        <translation>Header 2</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2169"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2278"/>
         <source>Header 3</source>
-        <translation type="unfinished"></translation>
+        <translation>Header 3</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2174"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2272"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2283"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2381"/>
         <source>3rd Item</source>
-        <translation type="unfinished"></translation>
+        <translation>3. Genstand</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2182"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2260"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2291"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2369"/>
         <source>2nd Item</source>
-        <translation type="unfinished"></translation>
+        <translation>2. Genstand</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2186"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2222"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2295"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2331"/>
         <source>2nd Child</source>
-        <translation type="unfinished"></translation>
+        <translation>2. Underligende</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2191"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2227"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2300"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2336"/>
         <source>1st Child</source>
-        <translation type="unfinished"></translation>
+        <translation>1. Underligende</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2197"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2245"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2306"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2354"/>
         <source>1st Item</source>
-        <translation type="unfinished"></translation>
+        <translation>1. Punkt</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2217"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2326"/>
         <source>3rd Child</source>
-        <translation type="unfinished"></translation>
+        <translation>3. Underligende</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2515"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2624"/>
         <source>Row 0</source>
-        <translation type="unfinished"></translation>
+        <translation>Række 0</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2520"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2629"/>
         <source>Row 1</source>
-        <translation type="unfinished"></translation>
+        <translation>Række 1</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2525"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2634"/>
         <source>Column 0</source>
-        <translation type="unfinished"></translation>
+        <translation>Kolonne 0</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2533"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2642"/>
         <source>Column 1</source>
-        <translation type="unfinished"></translation>
+        <translation>Kolonne 1</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2538"/>
-        <source>0-0</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2546"/>
-        <source>0-1</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2554"/>
-        <source>1-0</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2562"/>
-        <source>1-1</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2204"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2207"/>
-        <source>Editable</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2234"/>
-        <source>Non-Editable</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2282"/>
-        <source>Subwindow</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2329"/>
-        <source>Panel frame</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2348"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2489"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2581"/>
-        <source>GroupBox</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2368"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2420"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2714"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2791"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2839"/>
-        <source>Tab 1</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2374"/>
-        <source>Page 1 (disabled)</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2386"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2434"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2732"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2805"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2853"/>
-        <source>Tab 2</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2392"/>
-        <source>Page 2 (disabled)</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2426"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2619"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2674"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2797"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2845"/>
-        <source>Page 1</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2440"/>
         <location filename="../../KvantumPreviewBase.ui" line="2647"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2687"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2738"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2811"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2859"/>
-        <source>Page 2</source>
-        <translation type="unfinished"></translation>
+        <source>0-0</source>
+        <translation>0-0</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2464"/>
-        <source>Stack widget (page1)</source>
-        <translation type="unfinished"></translation>
+        <location filename="../../KvantumPreviewBase.ui" line="2655"/>
+        <source>0-1</source>
+        <translation>0-1</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2478"/>
-        <source>Stack Widget (page2)</source>
-        <translation type="unfinished"></translation>
+        <location filename="../../KvantumPreviewBase.ui" line="2663"/>
+        <source>1-0</source>
+        <translation>1-0</translation>
+    </message>
+    <message>
+        <location filename="../../KvantumPreviewBase.ui" line="2671"/>
+        <source>1-1</source>
+        <translation>1-1</translation>
+    </message>
+    <message>
+        <location filename="../../KvantumPreviewBase.ui" line="2313"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2316"/>
+        <source>Editable</source>
+        <translation>Redigerbar</translation>
+    </message>
+    <message>
+        <location filename="../../KvantumPreviewBase.ui" line="2343"/>
+        <source>Non-Editable</source>
+        <translation>Ikke redigerbar</translation>
+    </message>
+    <message>
+        <location filename="../../KvantumPreviewBase.ui" line="2391"/>
+        <source>Subwindow</source>
+        <translation>Undervindue</translation>
+    </message>
+    <message>
+        <location filename="../../KvantumPreviewBase.ui" line="2438"/>
+        <source>Panel frame</source>
+        <translation>Panelramme</translation>
+    </message>
+    <message>
+        <location filename="../../KvantumPreviewBase.ui" line="2457"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2598"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2690"/>
+        <source>GroupBox</source>
+        <translation>Gruppeboks</translation>
+    </message>
+    <message>
+        <location filename="../../KvantumPreviewBase.ui" line="2477"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2529"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2823"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2900"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2948"/>
+        <source>Tab 1</source>
+        <translation>Tab 1</translation>
+    </message>
+    <message>
+        <location filename="../../KvantumPreviewBase.ui" line="2483"/>
+        <source>Page 1 (disabled)</source>
+        <translation>Side 1 (deaktiveret)</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="2495"/>
-        <source>Group box</source>
-        <translation type="unfinished"></translation>
+        <location filename="../../KvantumPreviewBase.ui" line="2543"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2841"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2914"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2962"/>
+        <source>Tab 2</source>
+        <translation>Tab 2</translation>
+    </message>
+    <message>
+        <location filename="../../KvantumPreviewBase.ui" line="2501"/>
+        <source>Page 2 (disabled)</source>
+        <translation>Side 2 (deaktiveret)</translation>
+    </message>
+    <message>
+        <location filename="../../KvantumPreviewBase.ui" line="2535"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2728"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2783"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2906"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2954"/>
+        <source>Page 1</source>
+        <translation>Side 1</translation>
+    </message>
+    <message>
+        <location filename="../../KvantumPreviewBase.ui" line="2549"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2756"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2796"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2847"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2920"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2968"/>
+        <source>Page 2</source>
+        <translation>Side 2</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="2573"/>
+        <source>Stack widget (page1)</source>
+        <translation>Indbygget widget (side 1)</translation>
+    </message>
+    <message>
+        <location filename="../../KvantumPreviewBase.ui" line="2587"/>
+        <source>Stack Widget (page2)</source>
+        <translation>Indbygget widget (side 2)</translation>
+    </message>
+    <message>
+        <location filename="../../KvantumPreviewBase.ui" line="2604"/>
+        <source>Group box</source>
+        <translation>Gruppeboks</translation>
+    </message>
+    <message>
+        <location filename="../../KvantumPreviewBase.ui" line="2682"/>
         <source>Dock Widget</source>
-        <translation type="unfinished"></translation>
+        <translation>Flydende Widget</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2590"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2699"/>
         <source>Checkable group box</source>
-        <translation type="unfinished"></translation>
+        <translation>Afkrydsningsbar gruppeboks</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2625"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2734"/>
         <source>Tool Box</source>
-        <translation type="unfinished"></translation>
+        <translation>Værktøjskasse</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2720"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2829"/>
         <source>Document mode</source>
-        <translation type="unfinished"></translation>
+        <translation>Dokumenttilstand</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2758"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2867"/>
         <source>Box frame</source>
-        <translation type="unfinished"></translation>
+        <translation>Kasseramme</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2888"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2997"/>
         <source>&amp;File</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Fil</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2892"/>
+        <location filename="../../KvantumPreviewBase.ui" line="3001"/>
         <source>&amp;Submenu</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Undermenu</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2912"/>
+        <location filename="../../KvantumPreviewBase.ui" line="3021"/>
         <source>toolBar</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2932"/>
-        <source>toolBar_2</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2954"/>
-        <source>&amp;Quit</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2957"/>
-        <source>Quit</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2960"/>
-        <source>Ctrl+Q</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2968"/>
-        <source>&amp;Checkbox</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2981"/>
-        <source>Toggle Layout</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2984"/>
-        <source>Toggle layout direction</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2996"/>
-        <source>&amp;Doc Mode</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2999"/>
-        <source>Show tabs in the document mode</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../KvantumPreviewBase.ui" line="3011"/>
-        <source>Menu Button</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../KvantumPreviewBase.ui" line="3014"/>
-        <source>Hold pressed to show a menu</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../KvantumPreviewBase.ui" line="3025"/>
-        <source>C&amp;heckbox</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../KvantumPreviewBase.ui" line="3033"/>
-        <source>&amp;Radio button</source>
-        <translation type="unfinished"></translation>
+        <translation>Værktøjslinje</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="3041"/>
+        <source>toolBar_2</source>
+        <translation>Værktøjslinje_2</translation>
+    </message>
+    <message>
+        <location filename="../../KvantumPreviewBase.ui" line="3063"/>
+        <source>&amp;Quit</source>
+        <translation>&amp;Afslut</translation>
+    </message>
+    <message>
+        <location filename="../../KvantumPreviewBase.ui" line="3066"/>
+        <source>Quit</source>
+        <translation>Afslut</translation>
+    </message>
+    <message>
+        <location filename="../../KvantumPreviewBase.ui" line="3069"/>
+        <source>Ctrl+Q</source>
+        <translation>Ctrl+Q</translation>
+    </message>
+    <message>
+        <location filename="../../KvantumPreviewBase.ui" line="3077"/>
+        <source>&amp;Checkbox</source>
+        <translation>&amp;Afkrydsningsfelt</translation>
+    </message>
+    <message>
+        <location filename="../../KvantumPreviewBase.ui" line="3090"/>
+        <source>Toggle Layout</source>
+        <translation>Skift layout</translation>
+    </message>
+    <message>
+        <location filename="../../KvantumPreviewBase.ui" line="3093"/>
+        <source>Toggle layout direction</source>
+        <translation>Skift layoutretning</translation>
+    </message>
+    <message>
+        <location filename="../../KvantumPreviewBase.ui" line="3105"/>
+        <source>&amp;Doc Mode</source>
+        <translation>&amp;Dokumenttilstand</translation>
+    </message>
+    <message>
+        <location filename="../../KvantumPreviewBase.ui" line="3108"/>
+        <source>Show tabs in the document mode</source>
+        <translation>Vis faner i dokumenttilstand</translation>
+    </message>
+    <message>
+        <location filename="../../KvantumPreviewBase.ui" line="3120"/>
+        <source>Menu Button</source>
+        <translation>Menu knap</translation>
+    </message>
+    <message>
+        <location filename="../../KvantumPreviewBase.ui" line="3123"/>
+        <source>Hold pressed to show a menu</source>
+        <translation>Hold nede for at vise en menu</translation>
+    </message>
+    <message>
+        <location filename="../../KvantumPreviewBase.ui" line="3134"/>
+        <source>C&amp;heckbox</source>
+        <translation>Af&amp;krydsningsfelt</translation>
+    </message>
+    <message>
+        <location filename="../../KvantumPreviewBase.ui" line="3142"/>
+        <source>&amp;Radio button</source>
+        <translation>&amp;Radio knap</translation>
+    </message>
+    <message>
+        <location filename="../../KvantumPreviewBase.ui" line="3150"/>
         <source>Radio &amp;button</source>
-        <translation type="unfinished"></translation>
+        <translation>Radio &amp;knap</translation>
     </message>
 </context>
 </TS>
