@@ -11,7 +11,7 @@
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="29"/>
         <source>Push buttons</source>
-        <translation type="unfinished"></translation>
+        <translation>Κουμπιά πίεσης</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="77"/>
@@ -24,50 +24,61 @@ height
 greater
 than
 width</source>
-        <translation type="unfinished"></translation>
+        <translation>Εναλλαγή
+κουμπιού
+πίεσης
+
+με
+ύψος
+μεγαλύτερο
+από το
+πλάτος</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="95"/>
         <location filename="../../KvantumPreviewBase.ui" line="105"/>
         <source>Simple push button</source>
-        <translation type="unfinished"></translation>
+        <translation>Απλό κουμπί πίεσης</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="112"/>
         <location filename="../../KvantumPreviewBase.ui" line="128"/>
         <source>Toggle push button</source>
-        <translation type="unfinished"></translation>
+        <translation>Εναλλαγή κουμπιού πίεσης</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="141"/>
         <location filename="../../KvantumPreviewBase.ui" line="152"/>
         <source>Multi-line
  push button</source>
-        <translation type="unfinished"></translation>
+        <translation>Κουμπί πίεσης
+πολλαπλών γραμμών</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="160"/>
         <location filename="../../KvantumPreviewBase.ui" line="180"/>
         <source>Push button
 with 32px folder icon</source>
-        <translation type="unfinished"></translation>
+        <translation>Κουμπί πίεσης
+με εικονίδιο φακέλου 32εικ</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="210"/>
         <location filename="../../KvantumPreviewBase.ui" line="224"/>
         <source>Default
 push button</source>
-        <translation type="unfinished"></translation>
+        <translation>Προκαθορισμένο
+κουμπί πίεσης</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="266"/>
         <source>Flat buttons</source>
-        <translation type="unfinished"></translation>
+        <translation>Επίπεδα κουμπιά</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="279"/>
         <source>Button Box</source>
-        <translation type="unfinished"></translation>
+        <translation>Πλαίσιο κουμπιών</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="374"/>
@@ -175,20 +186,21 @@ radio button</source>
         <location filename="../../KvantumPreviewBase.ui" line="891"/>
         <location filename="../../KvantumPreviewBase.ui" line="917"/>
         <source>Radio button with 32px SVG icon</source>
-        <translation type="unfinished"></translation>
+        <translation>Κουμπί επιλογών με 32εικ εικονίδιο SVG</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="940"/>
         <location filename="../../KvantumPreviewBase.ui" line="953"/>
         <source>Simple check box</source>
-        <translation type="unfinished"></translation>
+        <translation>Απλό πλαίσιο ελέγχου</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="963"/>
         <location filename="../../KvantumPreviewBase.ui" line="974"/>
         <source>Multi-line
 check box</source>
-        <translation type="unfinished"></translation>
+        <translation>Πλαίσιο ελέγχου
+πολλαπλών γραμμών</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="982"/>
@@ -200,7 +212,7 @@ check box</source>
         <location filename="../../KvantumPreviewBase.ui" line="1005"/>
         <location filename="../../KvantumPreviewBase.ui" line="1019"/>
         <source>Check box with icon</source>
-        <translation type="unfinished"></translation>
+        <translation>Πλαίσιο ελέγχου με εικονίδιο</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="1075"/>
@@ -209,11 +221,11 @@ check box</source>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="1109"/>
-        <location filename="../../KvantumPreviewBase.ui" line="1195"/>
-        <location filename="../../KvantumPreviewBase.ui" line="1264"/>
-        <location filename="../../KvantumPreviewBase.ui" line="1378"/>
-        <location filename="../../KvantumPreviewBase.ui" line="1450"/>
-        <location filename="../../KvantumPreviewBase.ui" line="1508"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1198"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1271"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1433"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1515"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1607"/>
         <source>Frameless (no difference)</source>
         <translation type="unfinished"></translation>
     </message>
@@ -231,425 +243,437 @@ check box</source>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="1137"/>
-        <location filename="../../KvantumPreviewBase.ui" line="1173"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1176"/>
         <source>Standard combo box 2</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="1142"/>
-        <location filename="../../KvantumPreviewBase.ui" line="1178"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1181"/>
         <source>Standard combo box 3</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="1147"/>
-        <location filename="../../KvantumPreviewBase.ui" line="1183"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1186"/>
         <source>Standard combo box 4</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="1204"/>
-        <location filename="../../KvantumPreviewBase.ui" line="1273"/>
-        <location filename="../../KvantumPreviewBase.ui" line="1387"/>
-        <location filename="../../KvantumPreviewBase.ui" line="1459"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1207"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1280"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1442"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1524"/>
         <source>Frameless 1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="1209"/>
-        <location filename="../../KvantumPreviewBase.ui" line="1278"/>
-        <location filename="../../KvantumPreviewBase.ui" line="1392"/>
-        <location filename="../../KvantumPreviewBase.ui" line="1464"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1216"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1289"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1451"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1533"/>
         <source>Frameless 2</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="1214"/>
-        <location filename="../../KvantumPreviewBase.ui" line="1283"/>
-        <location filename="../../KvantumPreviewBase.ui" line="1397"/>
-        <location filename="../../KvantumPreviewBase.ui" line="1469"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1221"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1294"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1456"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1538"/>
         <source>Frameless 3</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="1219"/>
-        <location filename="../../KvantumPreviewBase.ui" line="1288"/>
-        <location filename="../../KvantumPreviewBase.ui" line="1402"/>
-        <location filename="../../KvantumPreviewBase.ui" line="1474"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1226"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1299"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1461"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1543"/>
         <source>Frameless 4</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="1224"/>
-        <location filename="../../KvantumPreviewBase.ui" line="1407"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1231"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1304"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1466"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1548"/>
         <source>Frameless 5</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="1229"/>
-        <location filename="../../KvantumPreviewBase.ui" line="1412"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1236"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1309"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1471"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1553"/>
         <source>Frameless 6</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="1234"/>
-        <location filename="../../KvantumPreviewBase.ui" line="1417"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1241"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1314"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1476"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1558"/>
         <source>Frameless 7</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="1239"/>
-        <location filename="../../KvantumPreviewBase.ui" line="1422"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1246"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1319"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1481"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1563"/>
         <source>Frameless 8</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="1244"/>
-        <location filename="../../KvantumPreviewBase.ui" line="1427"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1251"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1324"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1486"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1568"/>
         <source>Frameless 9</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="1249"/>
-        <location filename="../../KvantumPreviewBase.ui" line="1432"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1256"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1329"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1491"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1573"/>
         <source>Frameless 10</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="1300"/>
-        <location filename="../../KvantumPreviewBase.ui" line="1339"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1341"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1384"/>
         <source>Editable combo box</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="1309"/>
-        <location filename="../../KvantumPreviewBase.ui" line="1348"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1350"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1393"/>
         <source>Editable combo box 1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="1314"/>
-        <location filename="../../KvantumPreviewBase.ui" line="1353"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1359"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1402"/>
         <source>Editable combo box 2</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="1319"/>
-        <location filename="../../KvantumPreviewBase.ui" line="1358"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1364"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1407"/>
         <source>Editable combo box 3</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="1324"/>
-        <location filename="../../KvantumPreviewBase.ui" line="1363"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1369"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1412"/>
         <source>Editable combo box 4</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="1482"/>
-        <location filename="../../KvantumPreviewBase.ui" line="1495"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1581"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1594"/>
         <source>Line-edit</source>
-        <translation type="unfinished"></translation>
+        <translation>Γραμμή επεξεργασίας</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="1574"/>
+        <location filename="../../KvantumPreviewBase.ui" line="1683"/>
         <source>Sliders/Scrolls/Progress/Dial</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2131"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2240"/>
         <source>Containers</source>
-        <translation type="unfinished"></translation>
+        <translation>Υποδοχείς</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2152"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2261"/>
         <source>Header 1</source>
-        <translation type="unfinished"></translation>
+        <translation>Κεφαλίδα 1</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2161"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2270"/>
         <source>Header 2</source>
-        <translation type="unfinished"></translation>
+        <translation>Κεφαλίδα 2</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2169"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2278"/>
         <source>Header 3</source>
-        <translation type="unfinished"></translation>
+        <translation>Κεφαλίδα 3</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2174"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2272"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2283"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2381"/>
         <source>3rd Item</source>
-        <translation type="unfinished"></translation>
+        <translation>3ο αντικείμενο</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2182"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2260"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2291"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2369"/>
         <source>2nd Item</source>
-        <translation type="unfinished"></translation>
+        <translation>2ο αντικείμενο</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2186"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2222"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2295"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2331"/>
         <source>2nd Child</source>
-        <translation type="unfinished"></translation>
+        <translation>2ο τέκνο</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2191"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2227"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2300"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2336"/>
         <source>1st Child</source>
-        <translation type="unfinished"></translation>
+        <translation>1ο τέκνο</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2197"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2245"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2306"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2354"/>
         <source>1st Item</source>
-        <translation type="unfinished"></translation>
+        <translation>1ο αντικείμενο</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2217"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2326"/>
         <source>3rd Child</source>
-        <translation type="unfinished"></translation>
+        <translation>3ο τέκνο</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2515"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2624"/>
         <source>Row 0</source>
-        <translation type="unfinished"></translation>
+        <translation>Γραμμή 0</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2520"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2629"/>
         <source>Row 1</source>
-        <translation type="unfinished"></translation>
+        <translation>Γραμμή 1</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2525"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2634"/>
         <source>Column 0</source>
-        <translation type="unfinished"></translation>
+        <translation>Στήλη 0</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2533"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2642"/>
         <source>Column 1</source>
-        <translation type="unfinished"></translation>
+        <translation>Στήλη 1</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2538"/>
-        <source>0-0</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2546"/>
-        <source>0-1</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2554"/>
-        <source>1-0</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2562"/>
-        <source>1-1</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2204"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2207"/>
-        <source>Editable</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2234"/>
-        <source>Non-Editable</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2282"/>
-        <source>Subwindow</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2329"/>
-        <source>Panel frame</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2348"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2489"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2581"/>
-        <source>GroupBox</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2368"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2420"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2714"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2791"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2839"/>
-        <source>Tab 1</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2374"/>
-        <source>Page 1 (disabled)</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2386"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2434"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2732"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2805"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2853"/>
-        <source>Tab 2</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2392"/>
-        <source>Page 2 (disabled)</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2426"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2619"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2674"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2797"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2845"/>
-        <source>Page 1</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2440"/>
         <location filename="../../KvantumPreviewBase.ui" line="2647"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2687"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2738"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2811"/>
-        <location filename="../../KvantumPreviewBase.ui" line="2859"/>
-        <source>Page 2</source>
-        <translation type="unfinished"></translation>
+        <source>0-0</source>
+        <translation>0-0</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2464"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2655"/>
+        <source>0-1</source>
+        <translation>0-1</translation>
+    </message>
+    <message>
+        <location filename="../../KvantumPreviewBase.ui" line="2663"/>
+        <source>1-0</source>
+        <translation>1-0</translation>
+    </message>
+    <message>
+        <location filename="../../KvantumPreviewBase.ui" line="2671"/>
+        <source>1-1</source>
+        <translation>1-1</translation>
+    </message>
+    <message>
+        <location filename="../../KvantumPreviewBase.ui" line="2313"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2316"/>
+        <source>Editable</source>
+        <translation>Επεξεργάσιμο</translation>
+    </message>
+    <message>
+        <location filename="../../KvantumPreviewBase.ui" line="2343"/>
+        <source>Non-Editable</source>
+        <translation>Μη επεξεργάσιμο</translation>
+    </message>
+    <message>
+        <location filename="../../KvantumPreviewBase.ui" line="2391"/>
+        <source>Subwindow</source>
+        <translation>Υποπαράθυρο</translation>
+    </message>
+    <message>
+        <location filename="../../KvantumPreviewBase.ui" line="2438"/>
+        <source>Panel frame</source>
+        <translation>Πλαίσιο πίνακα</translation>
+    </message>
+    <message>
+        <location filename="../../KvantumPreviewBase.ui" line="2457"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2598"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2690"/>
+        <source>GroupBox</source>
+        <translation>Πλαίσιο ομαδοποίησης</translation>
+    </message>
+    <message>
+        <location filename="../../KvantumPreviewBase.ui" line="2477"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2529"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2823"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2900"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2948"/>
+        <source>Tab 1</source>
+        <translation>Καρτέλα 1</translation>
+    </message>
+    <message>
+        <location filename="../../KvantumPreviewBase.ui" line="2483"/>
+        <source>Page 1 (disabled)</source>
+        <translation>Σελίδα 1 (απενεργοποιημένο)</translation>
+    </message>
+    <message>
+        <location filename="../../KvantumPreviewBase.ui" line="2495"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2543"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2841"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2914"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2962"/>
+        <source>Tab 2</source>
+        <translation>Καρτέλα 2</translation>
+    </message>
+    <message>
+        <location filename="../../KvantumPreviewBase.ui" line="2501"/>
+        <source>Page 2 (disabled)</source>
+        <translation>Σελίδα 2 (απενεργοποιημένο)</translation>
+    </message>
+    <message>
+        <location filename="../../KvantumPreviewBase.ui" line="2535"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2728"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2783"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2906"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2954"/>
+        <source>Page 1</source>
+        <translation>Σελίδα 1</translation>
+    </message>
+    <message>
+        <location filename="../../KvantumPreviewBase.ui" line="2549"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2756"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2796"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2847"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2920"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2968"/>
+        <source>Page 2</source>
+        <translation>Σελίδα 2</translation>
+    </message>
+    <message>
+        <location filename="../../KvantumPreviewBase.ui" line="2573"/>
         <source>Stack widget (page1)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2478"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2587"/>
         <source>Stack Widget (page2)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2495"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2604"/>
         <source>Group box</source>
-        <translation type="unfinished"></translation>
+        <translation>Πλαίσιο ομαδοποίησης</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2573"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2682"/>
         <source>Dock Widget</source>
-        <translation type="unfinished"></translation>
+        <translation>Γραφικό συστατικό αποβάθρας</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2590"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2699"/>
         <source>Checkable group box</source>
-        <translation type="unfinished"></translation>
+        <translation>Επιλέξιμο πλαίσιο ομαδοποίησης</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2625"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2734"/>
         <source>Tool Box</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2720"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2829"/>
         <source>Document mode</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2758"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2867"/>
         <source>Box frame</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2888"/>
+        <location filename="../../KvantumPreviewBase.ui" line="2997"/>
         <source>&amp;File</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Αρχείο</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2892"/>
+        <location filename="../../KvantumPreviewBase.ui" line="3001"/>
         <source>&amp;Submenu</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Υπομενού</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2912"/>
+        <location filename="../../KvantumPreviewBase.ui" line="3021"/>
         <source>toolBar</source>
-        <translation type="unfinished"></translation>
+        <translation>γραμμή εργαλείων</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2932"/>
+        <location filename="../../KvantumPreviewBase.ui" line="3041"/>
         <source>toolBar_2</source>
-        <translation type="unfinished"></translation>
+        <translation>γραμμή εργαλείων_2</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2954"/>
+        <location filename="../../KvantumPreviewBase.ui" line="3063"/>
         <source>&amp;Quit</source>
-        <translation type="unfinished"></translation>
+        <translation>Έ&amp;ξοδος</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2957"/>
+        <location filename="../../KvantumPreviewBase.ui" line="3066"/>
         <source>Quit</source>
-        <translation type="unfinished"></translation>
+        <translation>Έξοδος</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2960"/>
+        <location filename="../../KvantumPreviewBase.ui" line="3069"/>
         <source>Ctrl+Q</source>
-        <translation type="unfinished"></translation>
+        <translation>Ctrl+Q</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2968"/>
+        <location filename="../../KvantumPreviewBase.ui" line="3077"/>
         <source>&amp;Checkbox</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Πλαίσιο ελέγχου</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2981"/>
+        <location filename="../../KvantumPreviewBase.ui" line="3090"/>
         <source>Toggle Layout</source>
-        <translation type="unfinished"></translation>
+        <translation>Εναλλαγή διάταξης</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2984"/>
+        <location filename="../../KvantumPreviewBase.ui" line="3093"/>
         <source>Toggle layout direction</source>
-        <translation type="unfinished"></translation>
+        <translation>Εναλλαγή κατεύθυνσης διάταξης</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2996"/>
+        <location filename="../../KvantumPreviewBase.ui" line="3105"/>
         <source>&amp;Doc Mode</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="2999"/>
+        <location filename="../../KvantumPreviewBase.ui" line="3108"/>
         <source>Show tabs in the document mode</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="3011"/>
+        <location filename="../../KvantumPreviewBase.ui" line="3120"/>
         <source>Menu Button</source>
-        <translation type="unfinished"></translation>
+        <translation>Κουμπί μενού</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="3014"/>
+        <location filename="../../KvantumPreviewBase.ui" line="3123"/>
         <source>Hold pressed to show a menu</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="3025"/>
+        <location filename="../../KvantumPreviewBase.ui" line="3134"/>
         <source>C&amp;heckbox</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Πλαίσιο ελέγχου</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="3033"/>
+        <location filename="../../KvantumPreviewBase.ui" line="3142"/>
         <source>&amp;Radio button</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Κουμπί επιλογής</translation>
     </message>
     <message>
-        <location filename="../../KvantumPreviewBase.ui" line="3041"/>
+        <location filename="../../KvantumPreviewBase.ui" line="3150"/>
         <source>Radio &amp;button</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Κουμπί επιλογής</translation>
     </message>
 </context>
 </TS>
