@@ -1,5 +1,5 @@
 /*
- * Copyright (C) Pedram Pourang (aka Tsu Jan) 2014-2019 <tsujan2000@gmail.com>
+ * Copyright (C) Pedram Pourang (aka Tsu Jan) 2014-2023 <tsujan2000@gmail.com>
  *
  * Kvantum is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -276,7 +276,9 @@ class Style : public QCommonStyle {
     void drawComboLineEdit(const QStyleOption *option,
                            QPainter *painter,
                            const QWidget *lineedit,
-                           const QWidget *combo) const;
+                           const QWidget *combo,
+                           const QString &group,
+                           bool fillInterior) const;
 
     /* Gets a pixmap with a proper size from an icon considering HDPI. */
     QPixmap getPixmapFromIcon(const QIcon &icon,
@@ -359,9 +361,6 @@ class Style : public QCommonStyle {
       forceButtonTextColor(const_cast<QWidget*>(widget), col);
     }
 
-    /* Opacifies a translucent color if opaciry is forced. */
-    void opacifyColor(QColor& col) const;
-
     /* Gets color from #rrggbbaa. */
     QColor getFromRGBA(const QString &str) const;
 
@@ -432,10 +431,6 @@ class Style : public QCommonStyle {
     }
 
   private slots:
-    /* For busy progress bars. */
-    void advanceProgressbar();
-    void forgetProgressBar(QObject *o);
-
     void forgetPopupOrigin(QObject *o);
 
     void forgetMovedMenu(QObject *o);
@@ -457,7 +452,7 @@ class Style : public QCommonStyle {
 
     QString xdg_config_home;
 
-    QTimer *progressTimer_, *opacityTimer_, *opacityTimerOut_;
+    QTimer *opacityTimer_, *opacityTimerOut_;
     mutable int animationOpacity_, animationOpacityOut_; // A value >= 100 stops state change animation.
     /* The start state for state change animation */
     mutable QString animationStartState_, animationStartStateOut_;
@@ -465,9 +460,6 @@ class Style : public QCommonStyle {
     QPointer<QWidget> animatedWidget_, animatedWidgetOut_;
     QHash<QWidget*, QPointer<QWidget>> popupOrigins_;
 
-    /* List of busy progress bars */
-    QMap<QWidget*,int> progressbars_;
-
     /* List of menus that are moved because of their shadows. */
     QSet<const QWidget*> movedMenus_;
 
