@@ -1,5 +1,5 @@
 /*
- * Copyright (C) Pedram Pourang (aka Tsu Jan) 2014-2022 <tsujan2000@gmail.com>
+ * Copyright (C) Pedram Pourang (aka Tsu Jan) 2014-2023 <tsujan2000@gmail.com>
  *
  * Kvantum is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -220,22 +220,8 @@ bool Style::eventFilter(QObject *o, QEvent *e)
     {
       if (w->inherits("KisAbstractSliderSpinBox") || w->inherits("Digikam::DAbstractSliderSpinBox"))
         isKisSlider_ = true;
-      else if (QProgressBar *pb = qobject_cast<QProgressBar*>(o))
-      {
-        if (pb->maximum() == 0 && pb->minimum() == 0)
-        { // add the busy progress bar to the list
-          if (!progressbars_.contains(w))
-          {
-            progressbars_.insert(w, 0);
-            connect(w, &QObject::destroyed, this, &Style::forgetProgressBar);
-            if (!progressTimer_->isActive())
-              progressTimer_->start(50);
-          }
-        }
-        else
-          forgetProgressBar(o);
+      else if (qobject_cast<QProgressBar*>(o))
         isKisSlider_ = false;
-      }
       else if (w->isWindow()
                && w->testAttribute(Qt::WA_StyledBackground)
                && w->testAttribute(Qt::WA_TranslucentBackground)
@@ -361,10 +347,7 @@ bool Style::eventFilter(QObject *o, QEvent *e)
             col = getFromRGBA(lspec.normalColor);
         }
         if (col.isValid())
-        {
-          opacifyColor(col);
           pPalette.setColor(QPalette::ButtonText, col);
-        }
 
         /* icon */
         if (!cbtn->icon().isNull())
@@ -860,8 +843,6 @@ bool Style::eventFilter(QObject *o, QEvent *e)
       QColor col = getFromRGBA(lspec.normalColor);
       if (!col.isValid())
         col = standardPalette().color(QPalette::Active,QPalette::Text);
-      else
-        opacifyColor(col);
       if (palette.color(QPalette::Inactive, QPalette::Text) != col)
       {
         _forcePalette = true;
@@ -876,7 +857,6 @@ bool Style::eventFilter(QObject *o, QEvent *e)
       /* set the toggled inactive text color to the toggled active one
          (the main purpose of installing an event filter on the view) */
       col = getFromRGBA(lspec.toggleColor);
-      opacifyColor(col);
       if (palette.color(QPalette::Inactive, QPalette::HighlightedText) != col)
       {
         _forcePalette = true;
@@ -914,8 +894,6 @@ bool Style::eventFilter(QObject *o, QEvent *e)
       QColor col = getFromRGBA(lspec.normalInactiveColor);
       if (!col.isValid())
         col = standardPalette().color(QPalette::Inactive,QPalette::Text);
-      else
-        opacifyColor(col);
       if (palette.color(QPalette::Inactive, QPalette::Text) != col)
       {
         _forcePalette = true;
@@ -929,7 +907,6 @@ bool Style::eventFilter(QObject *o, QEvent *e)
       }
       /* restore the toggled inactive text color (which was changed at QEvent::WindowActivate) */
       col = getFromRGBA(lspec.toggleInactiveColor);
-      opacifyColor(col);
       if (palette.color(QPalette::Inactive,QPalette::HighlightedText) != col)
       {
         _forcePalette = true;
@@ -960,20 +937,7 @@ bool Style::eventFilter(QObject *o, QEvent *e)
         connect(w, &QObject::destroyed, this, &Style::forgetPopupOrigin);
       }
 
-      if (QProgressBar *pb = qobject_cast<QProgressBar*>(o))
-      {
-        if (pb->maximum() == 0 && pb->minimum() == 0)
-        {
-          if (!progressbars_.contains(w))
-          {
-            progressbars_.insert(w, 0);
-            connect(w, &QObject::destroyed, this, &Style::forgetProgressBar);
-          }
-          if (!progressTimer_->isActive())
-            progressTimer_->start(50);
-        }
-      }
-      else if (QMenu *menu = qobject_cast<QMenu*>(o))
+      if (QMenu *menu = qobject_cast<QMenu*>(o))
       {
         //if (isLibreoffice_) break;
         if (w->testAttribute(Qt::WA_X11NetWmWindowTypeMenu)) break; // detached menu
@@ -1040,14 +1004,15 @@ bool Style::eventFilter(QObject *o, QEvent *e)
         }
         /* get the available geometry (Qt menus don't
            spread across the available virtual geometry) */
-        QRect sg, ag;
+        QRect ag;
+        //QRect sg;
         QScreen *sc = nullptr;
         if (QWindow *win = w->windowHandle())
         {
           sc = win->screen();
           if (sc)
           {
-            sg = sc->geometry();
+            //sg = sc->geometry();
             ag = sc->availableGeometry();
           }
         }
@@ -1125,17 +1090,36 @@ bool Style::eventFilter(QObject *o, QEvent *e)
             }
             else if (!ag.isEmpty())
             {
-              if (g.top() != ag.top()
-                  && (g.bottom() == ag.bottom()
-                      || QCursor::pos(sc).y() >= g.bottom()))
+              if (tspec_.isX11)
               {
-                dY += menuShadow_.at(1) + menuShadow_.at(3);
+                if (g.top() != ag.top()
+                    && (g.bottom() == ag.bottom()
+                        || QCursor::pos(sc).y() > g.bottom()))
+                {
+                  dY += menuShadow_.at(1) + menuShadow_.at(3);
+                }
+                if (g.right() != ag.right()
+                    && (g.left() == ag.left()
+                        || QCursor::pos(sc).x() <= g.left()))
+                {
+                  dX -= menuShadow_.at(2) + menuShadow_.at(0);
+                }
               }
-              if (g.right() != ag.right()
-                  && (g.left() == ag.left()
-                      || QCursor::pos(sc).x() <= g.left()))
+              else
               {
-                dX -= menuShadow_.at(2) + menuShadow_.at(0);
+                QRect pg;
+                if (QWidget *p = w->parentWidget())
+                  pg = p->window()->geometry();
+                if ((!pg.isNull() && g.bottom() + 1 == pg.top())
+                    || QCursor::pos(sc).y() > g.bottom())
+                {
+                  dY += menuShadow_.at(1) + menuShadow_.at(3);
+                }
+                if ((!pg.isNull() && g.left() == pg.right() + 1)
+                    || QCursor::pos(sc).x() <= g.left())
+                {
+                  dX -= menuShadow_.at(2) + menuShadow_.at(0);
+                }
               }
             }
           }
@@ -1194,19 +1178,40 @@ bool Style::eventFilter(QObject *o, QEvent *e)
             }
             else if (!ag.isEmpty()) // probably a panel menu
             {
-              /* snap to the screen bottom/right if possible and,
-                 as the last resort, consider the cursor position */
-              if (g.top() != ag.top()
-                  && (g.bottom() == ag.bottom()
-                      || QCursor::pos(sc).y() >= g.bottom()))
+              if (tspec_.isX11)
               {
-                dY += menuShadow_.at(1) + menuShadow_.at(3);
+                /* snap to the screen bottom/right if possible and,
+                   as the last resort, consider the cursor position */
+                if (g.top() != ag.top()
+                    && (g.bottom() == ag.bottom()
+                        || QCursor::pos(sc).y() > g.bottom()))
+                {
+                  dY += menuShadow_.at(1) + menuShadow_.at(3);
+                }
+                if (g.left() != ag.left()
+                    && (g.right() == ag.right()
+                        || QCursor::pos(sc).x() > g.right()))
+                {
+                  dX += menuShadow_.at(0) + menuShadow_.at(2);
+                }
               }
-              if (g.left() != ag.left()
-                  && (g.right() == ag.right()
-                      || QCursor::pos(sc).x() >= g.right() + 1))
+              else // the global position is unknown under Wayland
               {
-                dX += menuShadow_.at(0) + menuShadow_.at(2);
+                /* snap to the parent window's top/left side if needed and,
+                   as the last resort, consider the cursor position */
+                QRect pg;
+                if (QWidget *p = w->parentWidget())
+                  pg = p->window()->geometry();
+                if ((!pg.isNull() && g.bottom() + 1 == pg.top())
+                    || QCursor::pos(sc).y() > g.bottom())
+                {
+                  dY += menuShadow_.at(1) + menuShadow_.at(3);
+                }
+                if ((!pg.isNull() && g.right() + 1 == pg.left())
+                    || QCursor::pos(sc).x() > g.right())
+                {
+                  dX += menuShadow_.at(0) + menuShadow_.at(2);
+                }
               }
             }
           }
@@ -1244,8 +1249,9 @@ bool Style::eventFilter(QObject *o, QEvent *e)
         int DY = qRound(dY);
         if (DX == 0 && DY == 0) break;
 
+        /* This workaround isn't needed anymore. It didn't work with Wayland either. */
         // prevent the menu from switching to another screen
-        if (!sg.isEmpty() && QApplication::screens().size() > 1)
+        /*if (!sg.isEmpty() && QApplication::screens().size() > 1)
         {
           if (g.top() + DY < sg.top() && g.top() >= sg.top())
             DY = sg.top() - g.top();
@@ -1256,7 +1262,7 @@ bool Style::eventFilter(QObject *o, QEvent *e)
           }
           else if (g.left() + DX < sg.left() && g.left() >= sg.left())
             DX = sg.left() - g.left();
-        }
+        }*/
 
         w->move(g.left() + DX, g.top() + DY);
         movedMenus_.insert(w);
@@ -1289,8 +1295,6 @@ bool Style::eventFilter(QObject *o, QEvent *e)
           QColor col = getFromRGBA(lspec.normalInactiveColor);
           if (!col.isValid())
             col = standardPalette().color(QPalette::Inactive,QPalette::Text);
-          else
-            opacifyColor(col);
           if (palette.color(QPalette::Inactive, QPalette::Text) != col)
           {
             _forcePalette = true;
@@ -1303,7 +1307,6 @@ bool Style::eventFilter(QObject *o, QEvent *e)
             break;
           }
           col = getFromRGBA(lspec.toggleInactiveColor);
-          opacifyColor(col);
           if (palette.color(QPalette::Inactive,QPalette::HighlightedText) != col)
           {
             _forcePalette = true;
@@ -1324,8 +1327,6 @@ bool Style::eventFilter(QObject *o, QEvent *e)
           QColor col = getFromRGBA(lspec.normalColor);
           if (!col.isValid())
             col = standardPalette().color(QPalette::Active,QPalette::Text);
-          else
-            opacifyColor(col);
           if (palette.color(QPalette::Inactive, QPalette::Text) != col)
           {
             _forcePalette = true;
@@ -1338,7 +1339,6 @@ bool Style::eventFilter(QObject *o, QEvent *e)
             break;
           }
           col = getFromRGBA(lspec.toggleColor);
-          opacifyColor(col);
           if (palette.color(QPalette::Inactive, QPalette::HighlightedText) != col)
           {
             _forcePalette = true;
@@ -1408,22 +1408,18 @@ bool Style::eventFilter(QObject *o, QEvent *e)
       if (enoughContrast(col, standardPalette().color(QPalette::Active,QPalette::Text)))
       {
         QColor col1 = col;
-        opacifyColor(col1);
         QPalette palette = w->palette();
         palette.setColor(QPalette::Active, QPalette::Text, col1);
         if (!tspec_.no_inactiveness)
         {
           col1 = getFromRGBA(tlspec.normalInactiveColor);
           if (!col1.isValid()) col1 = col;
-          opacifyColor(col1);
         }
         palette.setColor(QPalette::Inactive, QPalette::Text, col1);
         col1 = col; // placeholder
         col1.setAlpha(128);
-        opacifyColor(col1);
         palette.setColor(QPalette::PlaceholderText, col1);
         col.setAlpha(102); // 0.4 * col.alpha()
-        opacifyColor(col);
         palette.setColor(QPalette::Disabled, QPalette::Text,col);
         forcePalette(w, palette);
         /* also correct the color of the symbolic clear icon (-> CE_ToolBar) */
@@ -1497,14 +1493,9 @@ bool Style::eventFilter(QObject *o, QEvent *e)
       /* remove the widget from some lists when it becomes hidden */
       if (qobject_cast<QMenu*>(w))
         forgetMovedMenu(o);
-      if (!progressbars_.isEmpty() && qobject_cast<QProgressBar*>(o))
-      {
-        forgetProgressBar(o);
-        break;
-      }
-      else if (tspec_.animate_states
-               && (w->windowType() == Qt::Popup
-                   || w->windowType() == Qt::ToolTip))
+      if (tspec_.animate_states
+          && (w->windowType() == Qt::Popup
+              || w->windowType() == Qt::ToolTip))
       {
         forgetPopupOrigin(o);
         break; // popups aren't animated (see below)
