@@ -1156,12 +1156,6 @@ hacks_spec ThemeConfig::getHacksSpec() const
   v = getValue(KSL("Hacks"),KSL("blur_translucent"));
   r.blur_translucent = v.toBool();
 
-#if (QT_VERSION == QT_VERSION_CHECK(5,14,0))
-  /* A workaround for a nasty bug about text translucency in Qt 5.14.0.
-     The bug was fixed in Qt 5.14.1. */
-  r.opaque_colors = true; // false by default
-#endif
-
   v = getValue(KSL("Hacks"),KSL("transparent_ktitle_label"));
   r.transparent_ktitle_label = v.toBool();
 
